/*******************************************************************************
 * Copyright (C) 2017 Philipp Spohr
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package de.hhu.ba.yoshikoWrapper.gui;


import java.awt.FlowLayout;

import javax.swing.BoxLayout;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JPanel;

import org.cytoscape.model.CyColumn;
import org.cytoscape.model.CyNetwork;

import de.hhu.ba.yoshikoWrapper.core.CyCore;

@SuppressWarnings("serial") //will never be serialized
public class ColumnMapper extends JPanel{
	

	//Swing components
	private final JComboBox<CyColumn> editingCostMapper;
	private final JComboBox<CyColumn> permanentMapper;
	private final JComboBox<CyColumn> forbiddenMapper;
		
	private final JCheckBox useMappingCost;
	private final JCheckBox useMappingPerm;
	private final JCheckBox useMappingForb;
	
	private final JPanel costGroup;
	private final JPanel permGroup;
	private final JPanel forbGroup;
		
	public ColumnMapper() {
		this.setLayout(new BoxLayout(this,BoxLayout.Y_AXIS));

		//SWING COMPONENTS
		
		//Combo-Boxes that map to the CyColumns
		editingCostMapper = new JComboBox<CyColumn>();
		permanentMapper = new JComboBox<CyColumn>();
		forbiddenMapper = new JComboBox<CyColumn>();
		
		//Should only be enabled if the option is checked
		editingCostMapper.setEnabled(false);
		permanentMapper.setEnabled(false);
		forbiddenMapper.setEnabled(false);

		useMappingCost = new JCheckBox("Map modification costs");
		useMappingPerm = new JCheckBox("Map edges as permanent");
		useMappingForb = new JCheckBox("Map edges as forbidden");
		
		useMappingCost.addActionListener(
			new EnableWhenSelectedListener(useMappingCost, editingCostMapper)
		);
		useMappingPerm.addActionListener(
			new EnableWhenSelectedListener(useMappingPerm, permanentMapper)
			);
		useMappingForb.addActionListener(
			new EnableWhenSelectedListener(useMappingForb, forbiddenMapper)
		);
		
		costGroup = new JPanel();
		permGroup = new JPanel();
		forbGroup = new JPanel();
		
		costGroup.setLayout(new FlowLayout());
		permGroup.setLayout(new FlowLayout());
		forbGroup.setLayout(new FlowLayout());

		SwingUtil.addAll(costGroup,useMappingCost,editingCostMapper);
		SwingUtil.addAll(permGroup,useMappingPerm,permanentMapper);
		SwingUtil.addAll(forbGroup,useMappingForb,forbiddenMapper);

		
		SwingUtil.addAll(this,costGroup,permGroup,forbGroup);
		
		//Initial call to get table values
		updateValues();

	}
	
	public void updateValues() {
		
		CyNetwork net = CyCore.cy.getCurrentNetwork();

		if (net != null) { //Check if a network is loaded
	
			//Clear entries
			editingCostMapper.removeAllItems();
			for (CyColumn c : net.getDefaultEdgeTable().getColumns()){
				//Only add columns with numeric values
				if (c.getType() == Integer.class || c.getType() == Double.class) {
					editingCostMapper.addItem(c);
				}
			}
			
			forbiddenMapper.removeAllItems();
			for (CyColumn c : net.getDefaultEdgeTable().getColumns()){
				//Only add columns with boolean values
				if (c.getType() == Boolean.class) {
					forbiddenMapper.addItem(c);
				}
			}
			
			permanentMapper.removeAllItems();
			for (CyColumn c : net.getDefaultEdgeTable().getColumns()){
				//Only add columns with boolean values
				if (c.getType() == Boolean.class) {
					permanentMapper.addItem(c);
				}
			}
		
		}
	}
	
	public CyColumn getEditingCostColumn() {
		if (useMappingCost.isSelected()) {
			return editingCostMapper.getItemAt(editingCostMapper.getSelectedIndex());
		}
		return null;
	}
	
	public CyColumn getForbiddenColumn() {
		if (useMappingForb.isSelected()) {
			return forbiddenMapper.getItemAt(forbiddenMapper.getSelectedIndex());
		}
		return null;
	}
	
	public CyColumn getPermanentColumn() {
		if (useMappingPerm.isSelected()) {
			return permanentMapper.getItemAt(permanentMapper.getSelectedIndex());
		}
		return null;
	}

}
